/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: RCSL 1.0/RPSL 1.0 
 *  
 * Portions Copyright (c) 1995-2002 RealNetworks, Inc. All Rights Reserved. 
 *      
 * The contents of this file, and the files included with this file, are 
 * subject to the current version of the RealNetworks Public Source License 
 * Version 1.0 (the "RPSL") available at 
 * http://www.helixcommunity.org/content/rpsl unless you have licensed 
 * the file under the RealNetworks Community Source License Version 1.0 
 * (the "RCSL") available at http://www.helixcommunity.org/content/rcsl, 
 * in which case the RCSL will apply. You may also obtain the license terms 
 * directly from RealNetworks.  You may not use this file except in 
 * compliance with the RPSL or, if you have a valid RCSL with RealNetworks 
 * applicable to this file, the RCSL.  Please see the applicable RPSL or 
 * RCSL for the rights, obligations and limitations governing use of the 
 * contents of the file.  
 *  
 * This file is part of the Helix DNA Technology. RealNetworks is the 
 * developer of the Original Code and owns the copyrights in the portions 
 * it created. 
 *  
 * This file, and the files included with this file, is distributed and made 
 * available on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESS OR IMPLIED, AND REALNETWORKS HEREBY DISCLAIMS ALL SUCH WARRANTIES, 
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS 
 * FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT. 
 * 
 * Technology Compatibility Kit Test Suite(s) Location: 
 *    http://www.helixcommunity.org/content/tck 
 * 
 * Contributor(s): 
 *  
 * ***** END LICENSE BLOCK ***** */ 

/**************************************************************************************
 * Fixed-point MP3 decoder
 * Jon Recker (jrecker@real.com), Ken Cooke (kenc@real.com)
 * June 2003
 *
 * 06.01.2014 - Recalculated Huff-Tables for Big-Value codes / M.Schmidt
 *              2108 vs. 4242 words for Huffman table (but slower)
 *
 * hufftabs.c - compressed Huffman code tables
 **************************************************************************************/

#include "coder.h"

/*
 * Tabelle wird mit Variabler Bit-Breite indiziert bis ein
 * dekodierter Wert gefunden wurde. Wird mit der gegebenen
 * Bit-Breite noch kein dekodierter Wert gefunden, so wird
 * ein Offset zum Springen innerhalb der Tabelle gelesen.
 * Der Offset ist speziell Codiert und nutzt aus, dass
 * alle Tabellen mindestens 1-Bit Breite haben.
 *
 * Es gibt folgende zwei Arten von Eintrgen in der Tabelle.
 *
 * ## Normaler Huffman-Code (Blatt-/Leaf-Eintrag) ##
 * Code-Aufbau: 0x0LXY
 * L=Lnge des Codes (1 bis 7)
 * X=X-Wert
 * Y=Y-Wert
 *
 * ## Sprung in Unter-Tabelle (Knoten-/Node-Eintrag) ##
 * Code-Aufbau: 0x0SPP
 * S=Oberstes Bit ist 1, restlichen 3 Bits sind die Gre der Sub-Tabelle-1 (also 0=1Bit-Tabelle)
 * PP=Halber Offset von der nchsten geraden Code-Position aus gesehen (siehe Code...)
 */

/* store Huffman codes as one big table plus table of offsets, since some platforms
 *   don't properly support table-of-tables (table of pointers to other const tables)
 */
 
// 2108x16Bit Wrter
// Lookup in maximal 3 Schritten
const unsigned short huffTable[] = {
  /* ## Huffman Code-Tabelle 1 ## */
  // LEVEL1 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code  und 1 Sub-Tabellen
  0x0802, 0x0210, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 00 und 0 Sub-Tabellen
  0x0111, 0x0101,


  /* ## Huffman Code-Tabelle 2 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 1 Sub-Tabellen
  0x0904, 0x0311, 0x0301, 0x0310, 0x0100, 0x0100, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code 000 und 1 Sub-Tabellen
  0x0802, 0x0212, 0x0221, 0x0220,
  // LEVEL3 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 00000 und 0 Sub-Tabellen
  0x0122, 0x0102,


  /* ## Huffman Code-Tabelle 3 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 1 Sub-Tabellen
  0x0904, 0x0310, 0x0211, 0x0211, 0x0201, 0x0201, 0x0200, 0x0200,
  // LEVEL2 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code 000 und 1 Sub-Tabellen
  0x0802, 0x0212, 0x0221, 0x0220,
  // LEVEL3 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 00000 und 0 Sub-Tabellen
  0x0122, 0x0102,


  /* ## Huffman Code-Tabelle 5 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 1 Sub-Tabellen
  0x0A04, 0x0311, 0x0301, 0x0310, 0x0100, 0x0100, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code 000 und 3 Sub-Tabellen
  0x0904, 0x0331, 0x0805, 0x0806, 0x0312, 0x0321, 0x0302, 0x0320,
  // LEVEL3 Tabellen - Lnge 8
  // Sub-Tabelle gre 2 mit vorherigen Code 000000 und 0 Sub-Tabellen
  0x0233, 0x0223, 0x0132, 0x0132,
  // Sub-Tabelle gre 1 mit vorherigen Code 000010 und 0 Sub-Tabellen
  0x0113, 0x0103,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011 und 0 Sub-Tabellen
  0x0130, 0x0122,


  /* ## Huffman Code-Tabelle 6 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 3 Sub-Tabellen
  0x0A04, 0x0908, 0x0809, 0x0301, 0x0211, 0x0211, 0x0310, 0x0300,
  // LEVEL2 Tabellen - Lnge 14
  // Sub-Tabelle gre 3 mit vorherigen Code 000 und 1 Sub-Tabellen
  0x0807, 0x0323, 0x0332, 0x0330, 0x0213, 0x0213, 0x0231, 0x0231,
  // Sub-Tabelle gre 2 mit vorherigen Code 001 und 0 Sub-Tabellen
  0x0222, 0x0202, 0x0112, 0x0112,
  // Sub-Tabelle gre 1 mit vorherigen Code 010 und 0 Sub-Tabellen
  0x0121, 0x0120,
  // LEVEL3 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 000000 und 0 Sub-Tabellen
  0x0133, 0x0103,


  /* ## Huffman Code-Tabelle 7 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 2 Sub-Tabellen
  0x0B04, 0x090C, 0x0301, 0x0310, 0x0100, 0x0100, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 20
  // Sub-Tabelle gre 4 mit vorherigen Code 000 und 7 Sub-Tabellen
  0x0A0A, 0x090E, 0x090F, 0x0911, 0x0812, 0x0414, 0x0441, 0x0440,
  0x0811, 0x0812, 0x0413, 0x0431, 0x0430, 0x0422, 0x0312, 0x0312,
  // Sub-Tabelle gre 2 mit vorherigen Code 001 und 1 Sub-Tabellen
  0x0221, 0x080F, 0x0111, 0x0111,
  // LEVEL3 Tabellen - Lnge 28
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000 und 0 Sub-Tabellen
  0x0355, 0x0345, 0x0354, 0x0353, 0x0235, 0x0235, 0x0244, 0x0244,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000001 und 0 Sub-Tabellen
  0x0225, 0x0252, 0x0115, 0x0115,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000010 und 0 Sub-Tabellen
  0x0151, 0x0151, 0x0205, 0x0234,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000011 und 0 Sub-Tabellen
  0x0150, 0x0150, 0x0243, 0x0233,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100 und 0 Sub-Tabellen
  0x0124, 0x0142,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001000 und 0 Sub-Tabellen
  0x0104, 0x0123,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001001 und 0 Sub-Tabellen
  0x0132, 0x0103,
  // Sub-Tabelle gre 1 mit vorherigen Code 00101 und 0 Sub-Tabellen
  0x0102, 0x0120,


  /* ## Huffman Code-Tabelle 8 ## */
  // LEVEL1 Tabellen - Lnge 16
  // Sub-Tabelle gre 4 mit vorherigen Code  und 2 Sub-Tabellen
  0x0B08, 0x0910, 0x0412, 0x0421, 0x0211, 0x0211, 0x0211, 0x0211,
  0x0301, 0x0301, 0x0310, 0x0310, 0x0200, 0x0200, 0x0200, 0x0200,
  // LEVEL2 Tabellen - Lnge 20
  // Sub-Tabelle gre 4 mit vorherigen Code 0000 und 5 Sub-Tabellen
  0x0A0A, 0x090E, 0x080F, 0x0415, 0x0451, 0x080F, 0x080F, 0x0424,
  0x0442, 0x0414, 0x0341, 0x0341, 0x0404, 0x0440, 0x0423, 0x0432,
  // Sub-Tabelle gre 2 mit vorherigen Code 0001 und 1 Sub-Tabellen
  0x090B, 0x0222, 0x0202, 0x0220,
  // LEVEL3 Tabellen - Lnge 22
  // Sub-Tabelle gre 3 mit vorherigen Code 00000000 und 0 Sub-Tabellen
  0x0355, 0x0354, 0x0245, 0x0245, 0x0153, 0x0153, 0x0153, 0x0153,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000001 und 0 Sub-Tabellen
  0x0235, 0x0244, 0x0125, 0x0125,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000010 und 0 Sub-Tabellen
  0x0152, 0x0105,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000101 und 0 Sub-Tabellen
  0x0134, 0x0143,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000110 und 0 Sub-Tabellen
  0x0150, 0x0133,
  // Sub-Tabelle gre 2 mit vorherigen Code 000100 und 0 Sub-Tabellen
  0x0213, 0x0231, 0x0203, 0x0230,


  /* ## Huffman Code-Tabelle 9 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 4 Sub-Tabellen
  0x0B04, 0x0A0C, 0x090F, 0x0811, 0x0311, 0x0301, 0x0310, 0x0300,
  // LEVEL2 Tabellen - Lnge 30
  // Sub-Tabelle gre 4 mit vorherigen Code 000 und 5 Sub-Tabellen
  0x090F, 0x0911, 0x0812, 0x0813, 0x0451, 0x0434, 0x0443, 0x0812,
  0x0424, 0x0442, 0x0433, 0x0440, 0x0314, 0x0314, 0x0341, 0x0341,
  // Sub-Tabelle gre 3 mit vorherigen Code 001 und 0 Sub-Tabellen
  0x0323, 0x0332, 0x0213, 0x0213, 0x0231, 0x0231, 0x0303, 0x0330,
  // Sub-Tabelle gre 2 mit vorherigen Code 010 und 0 Sub-Tabellen
  0x0222, 0x0202, 0x0112, 0x0112,
  // Sub-Tabelle gre 1 mit vorherigen Code 011 und 0 Sub-Tabellen
  0x0121, 0x0120,
  // LEVEL3 Tabellen - Lnge 14
  // Sub-Tabelle gre 2 mit vorherigen Code 0000000 und 0 Sub-Tabellen
  0x0255, 0x0245, 0x0135, 0x0135,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000001 und 0 Sub-Tabellen
  0x0153, 0x0153, 0x0254, 0x0205,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000010 und 0 Sub-Tabellen
  0x0144, 0x0125,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000011 und 0 Sub-Tabellen
  0x0152, 0x0115,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000111 und 0 Sub-Tabellen
  0x0150, 0x0104,


  /* ## Huffman Code-Tabelle 10 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 2 Sub-Tabellen
  0x0C04, 0x0814, 0x0301, 0x0310, 0x0100, 0x0100, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 34
  // Sub-Tabelle gre 5 mit vorherigen Code 000 und 13 Sub-Tabellen
  0x0A11, 0x0915, 0x0A16, 0x081A, 0x091A, 0x091C, 0x091D, 0x0517,
  0x0571, 0x081E, 0x091E, 0x0920, 0x0516, 0x0561, 0x0560, 0x0820,
  0x0820, 0x0821, 0x0514, 0x0541, 0x0540, 0x0523, 0x0532, 0x0503,
  0x0413, 0x0413, 0x0431, 0x0431, 0x0430, 0x0430, 0x0422, 0x0422,
  // Sub-Tabelle gre 1 mit vorherigen Code 001 und 1 Sub-Tabellen
  0x091A, 0x0111,
  // LEVEL3 Tabellen - Lnge 54
  // Sub-Tabelle gre 3 mit vorherigen Code 00000000 und 0 Sub-Tabellen
  0x0377, 0x0367, 0x0376, 0x0357, 0x0375, 0x0366, 0x0247, 0x0247,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000001 und 0 Sub-Tabellen
  0x0274, 0x0256, 0x0265, 0x0237,
  // Sub-Tabelle gre 3 mit vorherigen Code 00000010 und 0 Sub-Tabellen
  0x0273, 0x0273, 0x0246, 0x0246, 0x0355, 0x0354, 0x0263, 0x0263,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000011 und 0 Sub-Tabellen
  0x0127, 0x0172,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000100 und 0 Sub-Tabellen
  0x0264, 0x0207, 0x0170, 0x0170,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000101 und 0 Sub-Tabellen
  0x0162, 0x0162, 0x0245, 0x0235,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000110 und 0 Sub-Tabellen
  0x0106, 0x0106, 0x0253, 0x0244,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001001 und 0 Sub-Tabellen
  0x0136, 0x0126,
  // Sub-Tabelle gre 2 mit vorherigen Code 00001010 und 0 Sub-Tabellen
  0x0225, 0x0252, 0x0115, 0x0115,
  // Sub-Tabelle gre 2 mit vorherigen Code 00001011 und 0 Sub-Tabellen
  0x0151, 0x0151, 0x0234, 0x0243,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001111 und 0 Sub-Tabellen
  0x0105, 0x0150,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000 und 0 Sub-Tabellen
  0x0124, 0x0142,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010001 und 0 Sub-Tabellen
  0x0133, 0x0104,
  // Sub-Tabelle gre 2 mit vorherigen Code 0010 und 0 Sub-Tabellen
  0x0212, 0x0221, 0x0202, 0x0220,


  /* ## Huffman Code-Tabelle 11 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 3 Sub-Tabellen
  0x0C04, 0x0A14, 0x0917, 0x0311, 0x0301, 0x0310, 0x0200, 0x0200,
  // LEVEL2 Tabellen - Lnge 44
  // Sub-Tabelle gre 5 mit vorherigen Code 000 und 9 Sub-Tabellen
  0x0916, 0x0A18, 0x091B, 0x081D, 0x091D, 0x0527, 0x0572, 0x081E,
  0x0471, 0x0471, 0x0517, 0x0570, 0x0536, 0x0563, 0x0560, 0x081B,
  0x081B, 0x0515, 0x0462, 0x0462, 0x0526, 0x0506, 0x0416, 0x0416,
  0x0461, 0x0461, 0x0551, 0x0534, 0x0550, 0x0816, 0x0524, 0x0542,
  // Sub-Tabelle gre 3 mit vorherigen Code 001 und 3 Sub-Tabellen
  0x0915, 0x0817, 0x0313, 0x0331, 0x0816, 0x0322, 0x0221, 0x0221,
  // Sub-Tabelle gre 2 mit vorherigen Code 010 und 0 Sub-Tabellen
  0x0112, 0x0112, 0x0202, 0x0220,
  // LEVEL3 Tabellen - Lnge 38
  // Sub-Tabelle gre 2 mit vorherigen Code 00000000 und 0 Sub-Tabellen
  0x0277, 0x0267, 0x0276, 0x0275,
  // Sub-Tabelle gre 3 mit vorherigen Code 00000001 und 0 Sub-Tabellen
  0x0266, 0x0266, 0x0247, 0x0247, 0x0274, 0x0274, 0x0357, 0x0355,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000010 und 0 Sub-Tabellen
  0x0256, 0x0265, 0x0137, 0x0137,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000011 und 0 Sub-Tabellen
  0x0173, 0x0146,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000100 und 0 Sub-Tabellen
  0x0245, 0x0254, 0x0235, 0x0253,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000111 und 0 Sub-Tabellen
  0x0164, 0x0107,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001111 und 0 Sub-Tabellen
  0x0144, 0x0125,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000 und 0 Sub-Tabellen
  0x0152, 0x0105,
  // Sub-Tabelle gre 1 mit vorherigen Code 00011101 und 0 Sub-Tabellen
  0x0143, 0x0133,
  // Sub-Tabelle gre 2 mit vorherigen Code 001000 und 0 Sub-Tabellen
  0x0214, 0x0241, 0x0204, 0x0240,
  // Sub-Tabelle gre 1 mit vorherigen Code 001001 und 0 Sub-Tabellen
  0x0123, 0x0132,
  // Sub-Tabelle gre 1 mit vorherigen Code 001100 und 0 Sub-Tabellen
  0x0103, 0x0130,


  /* ## Huffman Code-Tabelle 12 ## */
  // LEVEL1 Tabellen - Lnge 16
  // Sub-Tabelle gre 4 mit vorherigen Code  und 7 Sub-Tabellen
  0x0B08, 0x0B10, 0x0A17, 0x091B, 0x091C, 0x081E, 0x0412, 0x0421,
  0x081D, 0x0400, 0x0311, 0x0311, 0x0301, 0x0301, 0x0310, 0x0310,
  // LEVEL2 Tabellen - Lnge 52
  // Sub-Tabelle gre 4 mit vorherigen Code 0000 und 6 Sub-Tabellen
  0x091A, 0x081C, 0x081C, 0x081D, 0x0456, 0x0437, 0x081C, 0x0427,
  0x0472, 0x0446, 0x0464, 0x0417, 0x0471, 0x081A, 0x0436, 0x0463,
  // Sub-Tabelle gre 4 mit vorherigen Code 0001 und 1 Sub-Tabellen
  0x0445, 0x0454, 0x0444, 0x0818, 0x0326, 0x0326, 0x0362, 0x0362,
  0x0361, 0x0361, 0x0416, 0x0460, 0x0435, 0x0453, 0x0425, 0x0452,
  // Sub-Tabelle gre 3 mit vorherigen Code 0010 und 1 Sub-Tabellen
  0x0315, 0x0351, 0x0334, 0x0343, 0x0810, 0x0324, 0x0342, 0x0314,
  // Sub-Tabelle gre 2 mit vorherigen Code 0011 und 0 Sub-Tabellen
  0x0233, 0x0241, 0x0223, 0x0232,
  // Sub-Tabelle gre 2 mit vorherigen Code 0100 und 1 Sub-Tabellen
  0x080D, 0x0230, 0x0113, 0x0113,
  // Sub-Tabelle gre 1 mit vorherigen Code 0101 und 0 Sub-Tabellen
  0x0131, 0x0122,
  // Sub-Tabelle gre 1 mit vorherigen Code 1000 und 0 Sub-Tabellen
  0x0102, 0x0120,
  // LEVEL3 Tabellen - Lnge 20
  // Sub-Tabelle gre 2 mit vorherigen Code 00000000 und 0 Sub-Tabellen
  0x0277, 0x0267, 0x0176, 0x0176,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001 und 0 Sub-Tabellen
  0x0157, 0x0175,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000010 und 0 Sub-Tabellen
  0x0166, 0x0147,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000011 und 0 Sub-Tabellen
  0x0174, 0x0165,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000110 und 0 Sub-Tabellen
  0x0173, 0x0155,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001101 und 0 Sub-Tabellen
  0x0107, 0x0170,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010011 und 0 Sub-Tabellen
  0x0106, 0x0105,
  // Sub-Tabelle gre 1 mit vorherigen Code 0010100 und 0 Sub-Tabellen
  0x0150, 0x0104,
  // Sub-Tabelle gre 1 mit vorherigen Code 010000 und 0 Sub-Tabellen
  0x0140, 0x0103,


  /* ## Huffman Code-Tabelle 13 ## */
  // LEVEL1 Tabellen - Lnge 64
  // Sub-Tabelle gre 6 mit vorherigen Code  und 12 Sub-Tabellen
  0x0E20, 0x0C60, 0x0C6F, 0x0A7F, 0x0B82, 0x0A8A, 0x0A8D, 0x0A91,
  0x0994, 0x0996, 0x0897, 0x0898, 0x0612, 0x0621, 0x0602, 0x0620,
  0x0411, 0x0411, 0x0411, 0x0411, 0x0401, 0x0401, 0x0401, 0x0401,
  0x0310, 0x0310, 0x0310, 0x0310, 0x0310, 0x0310, 0x0310, 0x0310,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 252
  // Sub-Tabelle gre 7 mit vorherigen Code 000000 und 20 Sub-Tabellen
  0x0D7E, 0x0B9E, 0x0AA5, 0x09A9, 0x0AAA, 0x0AAE, 0x09B1, 0x09B3,
  0x08B4, 0x08B5, 0x08B5, 0x08B6, 0x08B6, 0x09B7, 0x073F, 0x08B8,
  0x072F, 0x07F2, 0x08B7, 0x070F, 0x08B7, 0x07AB, 0x08B7, 0x074E,
  0x08B7, 0x073E, 0x07B9, 0x08B7, 0x061F, 0x061F, 0x06F1, 0x06F1,
  0x06F0, 0x06F0, 0x07BA, 0x07E5, 0x07E4, 0x078C, 0x076D, 0x07E3,
  0x06E2, 0x06E2, 0x072E, 0x070E, 0x061E, 0x061E, 0x06E1, 0x06E1,
  0x07E0, 0x075D, 0x07D5, 0x077C, 0x07C7, 0x074D, 0x078B, 0x07B8,
  0x07D4, 0x079A, 0x07A9, 0x076C, 0x06C6, 0x06C6, 0x063D, 0x063D,
  0x07D3, 0x077B, 0x062D, 0x062D, 0x06D2, 0x06D2, 0x061D, 0x061D,
  0x06B7, 0x06B7, 0x075C, 0x07C5, 0x0799, 0x077A, 0x06C3, 0x06C3,
  0x07A7, 0x0797, 0x064B, 0x064B, 0x05D1, 0x05D1, 0x05D1, 0x05D1,
  0x060D, 0x060D, 0x06D0, 0x06D0, 0x068A, 0x068A, 0x06A8, 0x06A8,
  0x064C, 0x064C, 0x06C4, 0x06C4, 0x066B, 0x066B, 0x06B6, 0x06B6,
  0x053C, 0x053C, 0x053C, 0x053C, 0x052C, 0x052C, 0x052C, 0x052C,
  0x05C2, 0x05C2, 0x05C2, 0x05C2, 0x055B, 0x055B, 0x055B, 0x055B,
  0x06B5, 0x06B5, 0x0689, 0x0689, 0x051C, 0x051C, 0x051C, 0x051C,
  // Sub-Tabelle gre 5 mit vorherigen Code 000001 und 7 Sub-Tabellen
  0x05C1, 0x0885, 0x05C0, 0x0885, 0x0885, 0x053B, 0x05B3, 0x0885,
  0x052B, 0x0885, 0x05A4, 0x0885, 0x0594, 0x0885, 0x04B2, 0x04B2,
  0x041B, 0x041B, 0x04B1, 0x04B1, 0x050B, 0x05B0, 0x0596, 0x054A,
  0x053A, 0x05A3, 0x0559, 0x0595, 0x042A, 0x042A, 0x04A2, 0x04A2,
  // Sub-Tabelle gre 5 mit vorherigen Code 000010 und 0 Sub-Tabellen
  0x041A, 0x041A, 0x04A1, 0x04A1, 0x050A, 0x0568, 0x04A0, 0x04A0,
  0x0586, 0x0549, 0x0493, 0x0493, 0x0539, 0x0558, 0x0585, 0x0567,
  0x0429, 0x0429, 0x0492, 0x0492, 0x0557, 0x0575, 0x0438, 0x0438,
  0x0483, 0x0483, 0x0566, 0x0547, 0x0574, 0x0556, 0x0565, 0x0573,
  // Sub-Tabelle gre 3 mit vorherigen Code 000011 und 3 Sub-Tabellen
  0x0319, 0x0391, 0x086B, 0x086C, 0x096C, 0x0328, 0x0382, 0x0318,
  // Sub-Tabelle gre 4 mit vorherigen Code 000100 und 0 Sub-Tabellen
  0x0437, 0x0427, 0x0317, 0x0317, 0x0371, 0x0371, 0x0455, 0x0407,
  0x0470, 0x0436, 0x0463, 0x0445, 0x0454, 0x0426, 0x0462, 0x0435,
  // Sub-Tabelle gre 3 mit vorherigen Code 000101 und 0 Sub-Tabellen
  0x0281, 0x0281, 0x0308, 0x0380, 0x0316, 0x0361, 0x0306, 0x0360,
  // Sub-Tabelle gre 3 mit vorherigen Code 000110 und 1 Sub-Tabellen
  0x0860, 0x0325, 0x0352, 0x0305, 0x0215, 0x0215, 0x0251, 0x0251,
  // Sub-Tabelle gre 3 mit vorherigen Code 000111 und 0 Sub-Tabellen
  0x0334, 0x0343, 0x0350, 0x0324, 0x0342, 0x0333, 0x0214, 0x0214,
  // Sub-Tabelle gre 2 mit vorherigen Code 001000 und 0 Sub-Tabellen
  0x0141, 0x0141, 0x0204, 0x0240,
  // Sub-Tabelle gre 2 mit vorherigen Code 001001 und 0 Sub-Tabellen
  0x0223, 0x0232, 0x0113, 0x0113,
  // Sub-Tabelle gre 1 mit vorherigen Code 001010 und 0 Sub-Tabellen
  0x0131, 0x0103,
  // Sub-Tabelle gre 1 mit vorherigen Code 001011 und 0 Sub-Tabellen
  0x0130, 0x0122,
  // LEVEL3 Tabellen - Lnge 166
  // Sub-Tabelle gre 6 mit vorherigen Code 0000000000000 und 0 Sub-Tabellen
  0x06FE, 0x06FC, 0x05FD, 0x05FD, 0x04ED, 0x04ED, 0x04ED, 0x04ED,
  0x03FF, 0x03FF, 0x03FF, 0x03FF, 0x03FF, 0x03FF, 0x03FF, 0x03FF,
  0x03EF, 0x03EF, 0x03EF, 0x03EF, 0x03EF, 0x03EF, 0x03EF, 0x03EF,
  0x03DF, 0x03DF, 0x03DF, 0x03DF, 0x03DF, 0x03DF, 0x03DF, 0x03DF,
  0x03EE, 0x03EE, 0x03EE, 0x03EE, 0x03EE, 0x03EE, 0x03EE, 0x03EE,
  0x03CF, 0x03CF, 0x03CF, 0x03CF, 0x03CF, 0x03CF, 0x03CF, 0x03CF,
  0x03DE, 0x03DE, 0x03DE, 0x03DE, 0x03DE, 0x03DE, 0x03DE, 0x03DE,
  0x03BF, 0x03BF, 0x03BF, 0x03BF, 0x03BF, 0x03BF, 0x03BF, 0x03BF,
  // Sub-Tabelle gre 4 mit vorherigen Code 0000000000001 und 0 Sub-Tabellen
  0x03FB, 0x03FB, 0x03CE, 0x03CE, 0x03DC, 0x03DC, 0x04AF, 0x04E9,
  0x02EC, 0x02EC, 0x02EC, 0x02EC, 0x02DD, 0x02DD, 0x02DD, 0x02DD,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000000010 und 0 Sub-Tabellen
  0x03FA, 0x03CD, 0x02BE, 0x02BE, 0x02EB, 0x02EB, 0x029F, 0x029F,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000000000011 und 0 Sub-Tabellen
  0x02F9, 0x02EA, 0x02BD, 0x02DB,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000000100 und 0 Sub-Tabellen
  0x028F, 0x028F, 0x02F8, 0x02F8, 0x02CC, 0x02CC, 0x03AE, 0x039E,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000000101 und 0 Sub-Tabellen
  0x028E, 0x028E, 0x037F, 0x037E, 0x01F7, 0x01F7, 0x01F7, 0x01F7,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000000000110 und 0 Sub-Tabellen
  0x01DA, 0x01DA, 0x02AD, 0x02BC,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000000000111 und 0 Sub-Tabellen
  0x02CB, 0x02F6, 0x016F, 0x016F,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000001000 und 0 Sub-Tabellen
  0x01E8, 0x015F,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000001001 und 0 Sub-Tabellen
  0x019D, 0x01D9,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000001010 und 0 Sub-Tabellen
  0x01F5, 0x01E7,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000001011 und 0 Sub-Tabellen
  0x01AC, 0x01BB,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000001100 und 0 Sub-Tabellen
  0x014F, 0x01F4,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000000001101 und 0 Sub-Tabellen
  0x02CA, 0x02E6, 0x01F3, 0x01F3,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000001111 und 0 Sub-Tabellen
  0x018D, 0x01D8,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000010010 und 0 Sub-Tabellen
  0x016E, 0x019C,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000010100 und 0 Sub-Tabellen
  0x01C9, 0x015E,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000010110 und 0 Sub-Tabellen
  0x017D, 0x01D7,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000011000 und 0 Sub-Tabellen
  0x01C8, 0x01D6,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000011011 und 0 Sub-Tabellen
  0x019B, 0x01AA,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000100001 und 0 Sub-Tabellen
  0x0198, 0x010C,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000100011 und 0 Sub-Tabellen
  0x01B4, 0x016A,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000100100 und 0 Sub-Tabellen
  0x01A6, 0x0179,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000100111 und 0 Sub-Tabellen
  0x0188, 0x015A,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000101001 und 0 Sub-Tabellen
  0x01A5, 0x0169,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000101011 und 0 Sub-Tabellen
  0x0178, 0x0187,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000101101 und 0 Sub-Tabellen
  0x0177, 0x0176,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011010 und 0 Sub-Tabellen
  0x0109, 0x0190,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011011 und 0 Sub-Tabellen
  0x0148, 0x0184,
  // Sub-Tabelle gre 2 mit vorherigen Code 000011100 und 0 Sub-Tabellen
  0x0172, 0x0172, 0x0246, 0x0264,
  // Sub-Tabelle gre 1 mit vorherigen Code 000110000 und 0 Sub-Tabellen
  0x0153, 0x0144,


  /* ## Huffman Code-Tabelle 15 ## */
  // LEVEL1 Tabellen - Lnge 32
  // Sub-Tabelle gre 5 mit vorherigen Code  und 15 Sub-Tabellen
  0x0D10, 0x0C30, 0x0C3F, 0x0B4F, 0x0B56, 0x085E, 0x0A5E, 0x0A62,
  0x0965, 0x0967, 0x0968, 0x096A, 0x086B, 0x096C, 0x086D, 0x0522,
  0x0512, 0x0521, 0x0502, 0x0520, 0x0311, 0x0311, 0x0311, 0x0311,
  0x0401, 0x0401, 0x0410, 0x0410, 0x0300, 0x0300, 0x0300, 0x0300,
  // LEVEL2 Tabellen - Lnge 202
  // Sub-Tabelle gre 6 mit vorherigen Code 00000 und 21 Sub-Tabellen
  0x0965, 0x0967, 0x0968, 0x096A, 0x086B, 0x086C, 0x086C, 0x086D,
  0x086D, 0x086E, 0x086E, 0x086F, 0x086F, 0x0870, 0x0870, 0x0971,
  0x06CB, 0x06F6, 0x0871, 0x0872, 0x06F5, 0x067E, 0x06E7, 0x06AC,
  0x06CA, 0x06BB, 0x086F, 0x064F, 0x06F4, 0x063F, 0x06F3, 0x06D8,
  0x06E6, 0x062F, 0x06F2, 0x086C, 0x061F, 0x06F1, 0x069C, 0x06C9,
  0x065E, 0x06AB, 0x06BA, 0x06E5, 0x067D, 0x06D7, 0x064E, 0x06E4,
  0x068C, 0x06C8, 0x063E, 0x066D, 0x06D6, 0x06E3, 0x069B, 0x06B9,
  0x062E, 0x06AA, 0x06E2, 0x061E, 0x06E1, 0x0860, 0x065D, 0x06D5,
  // Sub-Tabelle gre 5 mit vorherigen Code 00001 und 9 Sub-Tabellen
  0x085F, 0x0860, 0x05D4, 0x0860, 0x0860, 0x0861, 0x05D3, 0x05D2,
  0x0860, 0x051D, 0x057B, 0x05B7, 0x05D1, 0x085F, 0x05C5, 0x058A,
  0x05A8, 0x054C, 0x05C4, 0x056B, 0x05B6, 0x085C, 0x053C, 0x05C3,
  0x057A, 0x05A7, 0x05A6, 0x085A, 0x04C2, 0x04C2, 0x052C, 0x055B,
  // Sub-Tabelle gre 5 mit vorherigen Code 00010 und 0 Sub-Tabellen
  0x05B5, 0x051C, 0x0589, 0x0598, 0x05C1, 0x054B, 0x05B4, 0x056A,
  0x053B, 0x0579, 0x04B3, 0x04B3, 0x0597, 0x0588, 0x052B, 0x055A,
  0x04B2, 0x04B2, 0x05A5, 0x051B, 0x04B1, 0x04B1, 0x05B0, 0x0569,
  0x0596, 0x054A, 0x05A4, 0x0578, 0x0587, 0x053A, 0x04A3, 0x04A3,
  // Sub-Tabelle gre 4 mit vorherigen Code 00011 und 2 Sub-Tabellen
  0x0459, 0x0495, 0x042A, 0x04A2, 0x041A, 0x04A1, 0x0845, 0x0468,
  0x0486, 0x0449, 0x0494, 0x0439, 0x0493, 0x0843, 0x0458, 0x0485,
  // Sub-Tabelle gre 4 mit vorherigen Code 00100 und 0 Sub-Tabellen
  0x0429, 0x0467, 0x0476, 0x0492, 0x0391, 0x0391, 0x0419, 0x0490,
  0x0448, 0x0484, 0x0457, 0x0475, 0x0438, 0x0483, 0x0466, 0x0447,
  // Sub-Tabelle gre 1 mit vorherigen Code 00101 und 2 Sub-Tabellen
  0x093A, 0x0A3C,
  // Sub-Tabelle gre 3 mit vorherigen Code 00110 und 1 Sub-Tabellen
  0x0327, 0x0372, 0x0364, 0x0317, 0x0355, 0x0371, 0x083C, 0x0336,
  // Sub-Tabelle gre 3 mit vorherigen Code 00111 und 1 Sub-Tabellen
  0x0363, 0x0345, 0x0354, 0x0326, 0x0362, 0x0316, 0x0839, 0x0335,
  // Sub-Tabelle gre 2 mit vorherigen Code 01000 und 1 Sub-Tabellen
  0x0261, 0x0839, 0x0225, 0x0252,
  // Sub-Tabelle gre 2 mit vorherigen Code 01001 und 1 Sub-Tabellen
  0x0215, 0x0251, 0x0837, 0x0234,
  // Sub-Tabelle gre 2 mit vorherigen Code 01010 und 0 Sub-Tabellen
  0x0243, 0x0224, 0x0242, 0x0233,
  // Sub-Tabelle gre 2 mit vorherigen Code 01011 und 0 Sub-Tabellen
  0x0141, 0x0141, 0x0214, 0x0204,
  // Sub-Tabelle gre 1 mit vorherigen Code 01100 und 0 Sub-Tabellen
  0x0123, 0x0132,
  // Sub-Tabelle gre 2 mit vorherigen Code 01101 und 0 Sub-Tabellen
  0x0240, 0x0203, 0x0113, 0x0113,
  // Sub-Tabelle gre 1 mit vorherigen Code 01110 und 0 Sub-Tabellen
  0x0131, 0x0130,
  // LEVEL3 Tabellen - Lnge 94
  // Sub-Tabelle gre 2 mit vorherigen Code 00000000000 und 0 Sub-Tabellen
  0x02FF, 0x02EF, 0x02FE, 0x02DF,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000000001 und 0 Sub-Tabellen
  0x01EE, 0x01EE, 0x02FD, 0x02CF,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000000010 und 0 Sub-Tabellen
  0x02FC, 0x02DE, 0x02ED, 0x02BF,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000000011 und 0 Sub-Tabellen
  0x01FB, 0x01FB, 0x02CE, 0x02EC,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000000100 und 0 Sub-Tabellen
  0x01DD, 0x01AF,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000000101 und 0 Sub-Tabellen
  0x01FA, 0x01BE,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000000110 und 0 Sub-Tabellen
  0x01EB, 0x01CD,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000000111 und 0 Sub-Tabellen
  0x01DC, 0x019F,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001000 und 0 Sub-Tabellen
  0x01F9, 0x01EA,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001001 und 0 Sub-Tabellen
  0x01BD, 0x01DB,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001010 und 0 Sub-Tabellen
  0x018F, 0x01F8,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001011 und 0 Sub-Tabellen
  0x01CC, 0x019E,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001100 und 0 Sub-Tabellen
  0x01E9, 0x017F,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001101 und 0 Sub-Tabellen
  0x01F7, 0x01AD,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001110 und 0 Sub-Tabellen
  0x01DA, 0x01BC,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000001111 und 0 Sub-Tabellen
  0x016F, 0x016F, 0x02AE, 0x020F,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000010010 und 0 Sub-Tabellen
  0x018E, 0x01E8,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000010011 und 0 Sub-Tabellen
  0x015F, 0x019D,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000011010 und 0 Sub-Tabellen
  0x01D9, 0x018D,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000100011 und 0 Sub-Tabellen
  0x016E, 0x01F0,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000111101 und 0 Sub-Tabellen
  0x010E, 0x01E0,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100000 und 0 Sub-Tabellen
  0x017C, 0x01C7,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100001 und 0 Sub-Tabellen
  0x014D, 0x018B,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100011 und 0 Sub-Tabellen
  0x01B8, 0x019A,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100100 und 0 Sub-Tabellen
  0x01A9, 0x016C,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100101 und 0 Sub-Tabellen
  0x01C6, 0x013D,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101000 und 0 Sub-Tabellen
  0x012D, 0x010D,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101101 und 0 Sub-Tabellen
  0x015C, 0x01D0,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000110101 und 0 Sub-Tabellen
  0x0199, 0x010C,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000111011 und 0 Sub-Tabellen
  0x01C0, 0x010B,
  // Sub-Tabelle gre 1 mit vorherigen Code 000110110 und 0 Sub-Tabellen
  0x010A, 0x01A0,
  // Sub-Tabelle gre 1 mit vorherigen Code 000111101 und 0 Sub-Tabellen
  0x0177, 0x0109,
  // Sub-Tabelle gre 2 mit vorherigen Code 001010 und 0 Sub-Tabellen
  0x0228, 0x0282, 0x0218, 0x0281,
  // Sub-Tabelle gre 3 mit vorherigen Code 001011 und 0 Sub-Tabellen
  0x0374, 0x0308, 0x0380, 0x0356, 0x0365, 0x0337, 0x0373, 0x0346,
  // Sub-Tabelle gre 1 mit vorherigen Code 00110110 und 0 Sub-Tabellen
  0x0107, 0x0170,
  // Sub-Tabelle gre 1 mit vorherigen Code 00111110 und 0 Sub-Tabellen
  0x0106, 0x0160,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100001 und 0 Sub-Tabellen
  0x0153, 0x0144,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100110 und 0 Sub-Tabellen
  0x0105, 0x0150,


  /* ## Huffman Code-Tabelle 16 ## */
  // LEVEL1 Tabellen - Lnge 64
  // Sub-Tabelle gre 6 mit vorherigen Code  und 12 Sub-Tabellen
  0x0920, 0x0C22, 0x0931, 0x0D33, 0x0C52, 0x0B62, 0x0B69, 0x0A71,
  0x0A74, 0x0978, 0x0879, 0x097A, 0x0612, 0x0621, 0x0602, 0x0620,
  0x0411, 0x0411, 0x0411, 0x0411, 0x0401, 0x0401, 0x0401, 0x0401,
  0x0310, 0x0310, 0x0310, 0x0310, 0x0310, 0x0310, 0x0310, 0x0310,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 194
  // Sub-Tabelle gre 2 mit vorherigen Code 000000 und 3 Sub-Tabellen
  0x0A61, 0x0A65, 0x0968, 0x02FF,
  // Sub-Tabelle gre 5 mit vorherigen Code 000001 und 2 Sub-Tabellen
  0x045F, 0x045F, 0x04F5, 0x04F5, 0x034F, 0x034F, 0x034F, 0x034F,
  0x03F4, 0x03F4, 0x03F4, 0x03F4, 0x03F3, 0x03F3, 0x03F3, 0x03F3,
  0x03F0, 0x03F0, 0x03F0, 0x03F0, 0x043F, 0x043F, 0x0D5E, 0x0B7E,
  0x02F2, 0x02F2, 0x02F2, 0x02F2, 0x02F2, 0x02F2, 0x02F2, 0x02F2,
  // Sub-Tabelle gre 2 mit vorherigen Code 000010 und 2 Sub-Tabellen
  0x0881, 0x021F, 0x02F1, 0x0D81,
  // Sub-Tabelle gre 6 mit vorherigen Code 000011 und 9 Sub-Tabellen
  0x08A0, 0x08A1, 0x08A1, 0x060D, 0x08A1, 0x08A2, 0x08A2, 0x063C,
  0x08A2, 0x061C, 0x06C0, 0x08A2, 0x05E2, 0x05E2, 0x062E, 0x061E,
  0x06D3, 0x062D, 0x06D2, 0x06D1, 0x063B, 0x089E, 0x051D, 0x051D,
  0x06C4, 0x066B, 0x06C3, 0x06A7, 0x052C, 0x052C, 0x06C2, 0x06B5,
  0x06C1, 0x060C, 0x064B, 0x06B4, 0x066A, 0x06A6, 0x05B3, 0x05B3,
  0x065A, 0x06A5, 0x052B, 0x052B, 0x05B2, 0x05B2, 0x051B, 0x051B,
  0x05B1, 0x05B1, 0x060B, 0x06B0, 0x0669, 0x0696, 0x064A, 0x06A4,
  0x0678, 0x0687, 0x05A3, 0x05A3, 0x063A, 0x0659, 0x052A, 0x052A,
  // Sub-Tabelle gre 5 mit vorherigen Code 000100 und 3 Sub-Tabellen
  0x0889, 0x05A1, 0x0889, 0x0594, 0x0889, 0x0567, 0x04A2, 0x04A2,
  0x041A, 0x041A, 0x050A, 0x05A0, 0x0539, 0x0593, 0x0558, 0x0585,
  0x0429, 0x0429, 0x0492, 0x0492, 0x0576, 0x0509, 0x0419, 0x0419,
  0x0491, 0x0491, 0x0590, 0x0548, 0x0584, 0x0575, 0x0538, 0x0583,
  // Sub-Tabelle gre 4 mit vorherigen Code 000101 und 5 Sub-Tabellen
  0x087C, 0x0482, 0x087C, 0x0418, 0x0481, 0x0480, 0x087B, 0x0437,
  0x0473, 0x087B, 0x0427, 0x0472, 0x087A, 0x0407, 0x0317, 0x0317,
  // Sub-Tabelle gre 4 mit vorherigen Code 000110 und 0 Sub-Tabellen
  0x0371, 0x0371, 0x0470, 0x0436, 0x0463, 0x0445, 0x0454, 0x0426,
  0x0362, 0x0362, 0x0316, 0x0316, 0x0361, 0x0361, 0x0406, 0x0460,
  // Sub-Tabelle gre 3 mit vorherigen Code 000111 und 1 Sub-Tabellen
  0x0353, 0x0871, 0x0325, 0x0352, 0x0251, 0x0251, 0x0315, 0x0305,
  // Sub-Tabelle gre 3 mit vorherigen Code 001000 und 0 Sub-Tabellen
  0x0334, 0x0343, 0x0350, 0x0324, 0x0342, 0x0333, 0x0214, 0x0214,
  // Sub-Tabelle gre 2 mit vorherigen Code 001001 und 1 Sub-Tabellen
  0x0241, 0x086A, 0x0223, 0x0232,
  // Sub-Tabelle gre 1 mit vorherigen Code 001010 und 0 Sub-Tabellen
  0x0113, 0x0131,
  // Sub-Tabelle gre 2 mit vorherigen Code 001011 und 0 Sub-Tabellen
  0x0203, 0x0230, 0x0122, 0x0122,
  // LEVEL3 Tabellen - Lnge 204
  // Sub-Tabelle gre 3 mit vorherigen Code 00000000 und 0 Sub-Tabellen
  0x03EF, 0x03FE, 0x03DF, 0x03FD, 0x03CF, 0x03FC, 0x03BF, 0x03FB,
  // Sub-Tabelle gre 3 mit vorherigen Code 00000001 und 0 Sub-Tabellen
  0x02AF, 0x02AF, 0x03FA, 0x039F, 0x03F9, 0x03F8, 0x028F, 0x028F,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000010 und 0 Sub-Tabellen
  0x027F, 0x02F7, 0x026F, 0x02F6,
  // Sub-Tabelle gre 6 mit vorherigen Code 00000110110 und 0 Sub-Tabellen
  0x05CE, 0x05CE, 0x06EC, 0x06DD, 0x04DE, 0x04DE, 0x04DE, 0x04DE,
  0x04E9, 0x04E9, 0x04E9, 0x04E9, 0x05EA, 0x05EA, 0x05D9, 0x05D9,
  0x03EE, 0x03EE, 0x03EE, 0x03EE, 0x03EE, 0x03EE, 0x03EE, 0x03EE,
  0x04ED, 0x04ED, 0x04ED, 0x04ED, 0x04EB, 0x04EB, 0x04EB, 0x04EB,
  0x03BE, 0x03BE, 0x03BE, 0x03BE, 0x03BE, 0x03BE, 0x03BE, 0x03BE,
  0x03CD, 0x03CD, 0x03CD, 0x03CD, 0x03CD, 0x03CD, 0x03CD, 0x03CD,
  0x04DC, 0x04DC, 0x04DC, 0x04DC, 0x04DB, 0x04DB, 0x04DB, 0x04DB,
  0x03AE, 0x03AE, 0x03AE, 0x03AE, 0x03AE, 0x03AE, 0x03AE, 0x03AE,
  // Sub-Tabelle gre 4 mit vorherigen Code 00000110111 und 0 Sub-Tabellen
  0x03CC, 0x03CC, 0x04AD, 0x04DA, 0x047E, 0x04AC, 0x03CA, 0x03CA,
  0x04C9, 0x047D, 0x035E, 0x035E, 0x02BD, 0x02BD, 0x02BD, 0x02BD,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001000 und 0 Sub-Tabellen
  0x012F, 0x010F,
  // Sub-Tabelle gre 6 mit vorherigen Code 00001011 und 0 Sub-Tabellen
  0x059E, 0x059E, 0x06BC, 0x06CB, 0x068E, 0x06E8, 0x069D, 0x06E7,
  0x06BB, 0x068D, 0x06D8, 0x066E, 0x05E6, 0x05E6, 0x059C, 0x059C,
  0x06AB, 0x06BA, 0x06E5, 0x06D7, 0x054E, 0x054E, 0x06E4, 0x068C,
  0x05C8, 0x05C8, 0x053E, 0x053E, 0x056D, 0x056D, 0x06D6, 0x069B,
  0x06B9, 0x06AA, 0x05E1, 0x05E1, 0x05D4, 0x05D4, 0x06B8, 0x06A9,
  0x057B, 0x057B, 0x06B7, 0x06D0, 0x04E3, 0x04E3, 0x04E3, 0x04E3,
  0x050E, 0x050E, 0x05E0, 0x05E0, 0x055D, 0x055D, 0x05D5, 0x05D5,
  0x057C, 0x057C, 0x05C7, 0x05C7, 0x054D, 0x054D, 0x058B, 0x058B,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011000000 und 0 Sub-Tabellen
  0x019A, 0x016C,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011000001 und 0 Sub-Tabellen
  0x01C6, 0x013D,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011000010 und 0 Sub-Tabellen
  0x015C, 0x01C5,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011000100 und 0 Sub-Tabellen
  0x018A, 0x01A8,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011000101 und 0 Sub-Tabellen
  0x0199, 0x014C,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011000110 und 0 Sub-Tabellen
  0x01B6, 0x017A,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011001000 und 0 Sub-Tabellen
  0x015B, 0x0189,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011001011 und 0 Sub-Tabellen
  0x0198, 0x0179,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011010101 und 0 Sub-Tabellen
  0x0197, 0x0188,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000000 und 0 Sub-Tabellen
  0x0195, 0x0168,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000010 und 0 Sub-Tabellen
  0x0186, 0x0177,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000100 und 0 Sub-Tabellen
  0x0149, 0x0157,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001010000 und 0 Sub-Tabellen
  0x0166, 0x0128,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001010010 und 0 Sub-Tabellen
  0x0147, 0x0174,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001010110 und 0 Sub-Tabellen
  0x0108, 0x0156,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001011001 und 0 Sub-Tabellen
  0x0165, 0x0146,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001011100 und 0 Sub-Tabellen
  0x0164, 0x0155,
  // Sub-Tabelle gre 1 mit vorherigen Code 000111001 und 0 Sub-Tabellen
  0x0135, 0x0144,
  // Sub-Tabelle gre 1 mit vorherigen Code 00100101 und 0 Sub-Tabellen
  0x0104, 0x0140,


  /* ## Huffman Code-Tabelle 24 ## */
  // LEVEL1 Tabellen - Lnge 16
  // Sub-Tabelle gre 4 mit vorherigen Code  und 11 Sub-Tabellen
  0x0B08, 0x0A10, 0x0A13, 0x04FF, 0x0D16, 0x0C36, 0x0C45, 0x0B55,
  0x0A5C, 0x0A60, 0x0963, 0x0965, 0x0411, 0x0401, 0x0410, 0x0400,
  // LEVEL2 Tabellen - Lnge 200
  // Sub-Tabelle gre 4 mit vorherigen Code 0000 und 0 Sub-Tabellen
  0x04EF, 0x04FE, 0x04DF, 0x04FD, 0x04CF, 0x04FC, 0x04BF, 0x04FB,
  0x03FA, 0x03FA, 0x04AF, 0x049F, 0x03F9, 0x03F9, 0x03F8, 0x03F8,
  // Sub-Tabelle gre 3 mit vorherigen Code 0001 und 1 Sub-Tabellen
  0x085C, 0x03F7, 0x036F, 0x03F6, 0x035F, 0x03F5, 0x034F, 0x03F4,
  // Sub-Tabelle gre 3 mit vorherigen Code 0010 und 3 Sub-Tabellen
  0x033F, 0x03F3, 0x032F, 0x03F2, 0x03F1, 0x0857, 0x0B57, 0x0B5F,
  // Sub-Tabelle gre 6 mit vorherigen Code 0100 und 7 Sub-Tabellen
  0x0866, 0x0867, 0x0967, 0x06E6, 0x0868, 0x06C9, 0x065E, 0x06BA,
  0x06E5, 0x0867, 0x06D7, 0x06E4, 0x068C, 0x06C8, 0x0865, 0x063E,
  0x066D, 0x06D6, 0x06E3, 0x069B, 0x06B9, 0x06AA, 0x06E2, 0x061E,
  0x06E1, 0x065D, 0x06D5, 0x067C, 0x06C7, 0x064D, 0x068B, 0x06B8,
  0x06D4, 0x069A, 0x06A9, 0x066C, 0x06C6, 0x063D, 0x06D3, 0x062D,
  0x06D2, 0x061D, 0x067B, 0x06B7, 0x06D1, 0x065C, 0x06C5, 0x068A,
  0x06A8, 0x0699, 0x064C, 0x06C4, 0x066B, 0x06B6, 0x0852, 0x063C,
  0x06C3, 0x067A, 0x06A7, 0x062C, 0x06C2, 0x065B, 0x06B5, 0x061C,
  // Sub-Tabelle gre 5 mit vorherigen Code 0101 und 11 Sub-Tabellen
  0x084E, 0x084F, 0x094F, 0x0951, 0x05B4, 0x0852, 0x0852, 0x0953,
  0x05B3, 0x0588, 0x0853, 0x05B2, 0x0853, 0x0854, 0x0596, 0x05A4,
  0x0853, 0x0587, 0x053A, 0x05A3, 0x0559, 0x0595, 0x052A, 0x05A2,
  0x05A1, 0x0568, 0x0586, 0x0577, 0x0549, 0x0594, 0x0539, 0x0593,
  // Sub-Tabelle gre 5 mit vorherigen Code 0110 und 2 Sub-Tabellen
  0x0558, 0x0585, 0x0529, 0x0567, 0x0576, 0x0592, 0x0519, 0x0591,
  0x0548, 0x0584, 0x0557, 0x0575, 0x0538, 0x0583, 0x0566, 0x0528,
  0x0582, 0x0518, 0x0547, 0x0574, 0x0581, 0x0842, 0x0556, 0x0565,
  0x0517, 0x0841, 0x0473, 0x0473, 0x0537, 0x0527, 0x0472, 0x0472,
  // Sub-Tabelle gre 4 mit vorherigen Code 0111 und 1 Sub-Tabellen
  0x0446, 0x0464, 0x0455, 0x0471, 0x0436, 0x0463, 0x0445, 0x0454,
  0x0426, 0x0462, 0x0416, 0x0461, 0x0838, 0x0435, 0x0453, 0x0444,
  // Sub-Tabelle gre 3 mit vorherigen Code 1000 und 3 Sub-Tabellen
  0x0837, 0x0938, 0x0351, 0x0839, 0x0324, 0x0342, 0x0333, 0x0314,
  // Sub-Tabelle gre 3 mit vorherigen Code 1001 und 1 Sub-Tabellen
  0x0341, 0x0837, 0x0323, 0x0332, 0x0213, 0x0213, 0x0231, 0x0231,
  // Sub-Tabelle gre 2 mit vorherigen Code 1010 und 1 Sub-Tabellen
  0x0834, 0x0222, 0x0112, 0x0112,
  // Sub-Tabelle gre 2 mit vorherigen Code 1011 und 0 Sub-Tabellen
  0x0121, 0x0121, 0x0202, 0x0220,
  // LEVEL3 Tabellen - Lnge 98
  // Sub-Tabelle gre 1 mit vorherigen Code 0001000 und 0 Sub-Tabellen
  0x018F, 0x017F,
  // Sub-Tabelle gre 1 mit vorherigen Code 0010101 und 0 Sub-Tabellen
  0x011F, 0x01F0,
  // Sub-Tabelle gre 4 mit vorherigen Code 0010110 und 0 Sub-Tabellen
  0x020F, 0x020F, 0x020F, 0x020F, 0x04EE, 0x04DE, 0x04ED, 0x04CE,
  0x04EC, 0x04DD, 0x04BE, 0x04EB, 0x04CD, 0x04DC, 0x04AE, 0x04EA,
  // Sub-Tabelle gre 4 mit vorherigen Code 0010111 und 0 Sub-Tabellen
  0x04BD, 0x04DB, 0x04CC, 0x049E, 0x04E9, 0x04AD, 0x04DA, 0x04BC,
  0x04CB, 0x048E, 0x04E8, 0x049D, 0x04D9, 0x047E, 0x04E7, 0x04AC,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100000000 und 0 Sub-Tabellen
  0x01CA, 0x01BB,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100000001 und 0 Sub-Tabellen
  0x018D, 0x01D8,
  // Sub-Tabelle gre 2 mit vorherigen Code 0100000010 und 0 Sub-Tabellen
  0x020E, 0x02E0, 0x010D, 0x010D,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100000100 und 0 Sub-Tabellen
  0x016E, 0x019C,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100001001 und 0 Sub-Tabellen
  0x01AB, 0x017D,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100001110 und 0 Sub-Tabellen
  0x014E, 0x012E,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100110110 und 0 Sub-Tabellen
  0x01D0, 0x010C,
  // Sub-Tabelle gre 1 mit vorherigen Code 010100000 und 0 Sub-Tabellen
  0x0189, 0x0198,
  // Sub-Tabelle gre 1 mit vorherigen Code 010100001 und 0 Sub-Tabellen
  0x01C1, 0x014B,
  // Sub-Tabelle gre 2 mit vorherigen Code 010100010 und 0 Sub-Tabellen
  0x02C0, 0x020B, 0x013B, 0x013B,
  // Sub-Tabelle gre 2 mit vorherigen Code 010100011 und 0 Sub-Tabellen
  0x02B0, 0x020A, 0x011A, 0x011A,
  // Sub-Tabelle gre 1 mit vorherigen Code 010100101 und 0 Sub-Tabellen
  0x016A, 0x01A6,
  // Sub-Tabelle gre 1 mit vorherigen Code 010100110 und 0 Sub-Tabellen
  0x0179, 0x0197,
  // Sub-Tabelle gre 2 mit vorherigen Code 010100111 und 0 Sub-Tabellen
  0x02A0, 0x0209, 0x0190, 0x0190,
  // Sub-Tabelle gre 1 mit vorherigen Code 010101010 und 0 Sub-Tabellen
  0x012B, 0x015A,
  // Sub-Tabelle gre 1 mit vorherigen Code 010101100 und 0 Sub-Tabellen
  0x01A5, 0x011B,
  // Sub-Tabelle gre 1 mit vorherigen Code 010101101 und 0 Sub-Tabellen
  0x01B1, 0x0169,
  // Sub-Tabelle gre 1 mit vorherigen Code 010110000 und 0 Sub-Tabellen
  0x014A, 0x0178,
  // Sub-Tabelle gre 1 mit vorherigen Code 011010101 und 0 Sub-Tabellen
  0x0108, 0x0180,
  // Sub-Tabelle gre 1 mit vorherigen Code 011011001 und 0 Sub-Tabellen
  0x0107, 0x0170,
  // Sub-Tabelle gre 1 mit vorherigen Code 01111100 und 0 Sub-Tabellen
  0x0106, 0x0160,
  // Sub-Tabelle gre 1 mit vorherigen Code 1000000 und 0 Sub-Tabellen
  0x0125, 0x0152,
  // Sub-Tabelle gre 2 mit vorherigen Code 1000001 und 0 Sub-Tabellen
  0x0115, 0x0115, 0x0205, 0x0250,
  // Sub-Tabelle gre 1 mit vorherigen Code 1000011 und 0 Sub-Tabellen
  0x0134, 0x0143,
  // Sub-Tabelle gre 1 mit vorherigen Code 1001001 und 0 Sub-Tabellen
  0x0104, 0x0140,
  // Sub-Tabelle gre 1 mit vorherigen Code 101000 und 0 Sub-Tabellen
  0x0103, 0x0130,


  /* ## Huffman Code-Tabelle 32 ## */
  // LEVEL1 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code  und 2 Sub-Tabellen
  0x0A02, 0x0906, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 12
  // Sub-Tabelle gre 3 mit vorherigen Code 00 und 3 Sub-Tabellen
  0x0806, 0x0807, 0x0807, 0x0309, 0x0306, 0x0303, 0x030A, 0x030C,
  // Sub-Tabelle gre 2 mit vorherigen Code 01 und 0 Sub-Tabellen
  0x0202, 0x0201, 0x0204, 0x0208,
  // LEVEL3 Tabellen - Lnge 6
  // Sub-Tabelle gre 1 mit vorherigen Code 00000 und 0 Sub-Tabellen
  0x010B, 0x010F,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001 und 0 Sub-Tabellen
  0x010D, 0x010E,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010 und 0 Sub-Tabellen
  0x0107, 0x0105,


  /* ## Huffman Code-Tabelle 33 ## */
  // LEVEL1 Tabellen - Lnge 16
  // Sub-Tabelle gre 4 mit vorherigen Code  und 0 Sub-Tabellen
  0x040F, 0x040E, 0x040D, 0x040C, 0x040B, 0x040A, 0x0409, 0x0408,
  0x0407, 0x0406, 0x0405, 0x0404, 0x0403, 0x0402, 0x0401, 0x0400,


};


const HuffTabLookup HuffInfo[] = {
  { 0, 2, 0 }, // Huffman-Tabelle 1 (echt kodiert)
  { 0, 3, 6 }, // Huffman-Tabelle 2 (echt kodiert)
  { 0, 3, 20 }, // Huffman-Tabelle 3 (echt kodiert)
  { 0, 0, 0 }, // Huffman-Tabelle 4 (nicht kodiert)
  { 0, 3, 34 }, // Huffman-Tabelle 5 (echt kodiert)
  { 0, 3, 58 }, // Huffman-Tabelle 6 (echt kodiert)
  { 0, 3, 82 }, // Huffman-Tabelle 7 (echt kodiert)
  { 0, 4, 138 }, // Huffman-Tabelle 8 (echt kodiert)
  { 0, 3, 196 }, // Huffman-Tabelle 9 (echt kodiert)
  { 0, 3, 248 }, // Huffman-Tabelle 10 (echt kodiert)
  { 0, 3, 344 }, // Huffman-Tabelle 11 (echt kodiert)
  { 0, 4, 434 }, // Huffman-Tabelle 12 (echt kodiert)
  { 0, 6, 522 }, // Huffman-Tabelle 13 (echt kodiert)
  { 0, 0, 0 }, // Huffman-Tabelle 14 (nicht kodiert)
  { 0, 5, 1004 }, // Huffman-Tabelle 15 (echt kodiert)
  { 1, 6, 1332 }, // Huffman-Tabelle 16 (echt kodiert)
  { 2, 6, 1332 }, // Huffman-Tabelle 17 (nutzt 16)
  { 3, 6, 1332 }, // Huffman-Tabelle 18 (nutzt 16)
  { 4, 6, 1332 }, // Huffman-Tabelle 19 (nutzt 16)
  { 6, 6, 1332 }, // Huffman-Tabelle 20 (nutzt 16)
  { 8, 6, 1332 }, // Huffman-Tabelle 21 (nutzt 16)
  { 10, 6, 1332 }, // Huffman-Tabelle 22 (nutzt 16)
  { 13, 6, 1332 }, // Huffman-Tabelle 23 (nutzt 16)
  { 4, 4, 1794 }, // Huffman-Tabelle 24 (echt kodiert)
  { 5, 4, 1794 }, // Huffman-Tabelle 25 (nutzt 24)
  { 6, 4, 1794 }, // Huffman-Tabelle 26 (nutzt 24)
  { 7, 4, 1794 }, // Huffman-Tabelle 27 (nutzt 24)
  { 8, 4, 1794 }, // Huffman-Tabelle 28 (nutzt 24)
  { 9, 4, 1794 }, // Huffman-Tabelle 29 (nutzt 24)
  { 11, 4, 1794 }, // Huffman-Tabelle 30 (nutzt 24)
  { 13, 4, 1794 }, // Huffman-Tabelle 31 (nutzt 24)
  { 0, 2, 2108 }, // Huffman-Tabelle 32 (echt kodiert)
  { 0, 4, 2130 }, // Huffman-Tabelle 33 (echt kodiert)
};


/* tables for quadruples
 * format 0xAB
 *  A = length of codeword
 *  B = codeword
 */
const unsigned char quadTable[64+16] = {
	/* table A */
	0x6b, 0x6f, 0x6d, 0x6e, 0x67, 0x65, 0x59, 0x59, 
	0x56, 0x56, 0x53, 0x53, 0x5a, 0x5a, 0x5c, 0x5c, 
	0x42, 0x42, 0x42, 0x42, 0x41, 0x41, 0x41, 0x41, 
	0x44, 0x44, 0x44, 0x44, 0x48, 0x48, 0x48, 0x48, 
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
	/* table B */
	0x4f, 0x4e, 0x4d, 0x4c, 0x4b, 0x4a, 0x49, 0x48, 
	0x47, 0x46, 0x45, 0x44, 0x43, 0x42, 0x41, 0x40, 
};

const int quadTabOffset[2] = {0, 64};
const int quadTabMaxBits[2] = {6, 4};