// mp3dec.cpp : Definiert den Einstiegspunkt fr die Konsolenanwendung.
//

#include <SDL.h>
#include <SDL_audio.h>
#include "real\pub\mp3dec.h"

#define FALSE 0
#define TRUE 1

// Input-Buffer
#define MP3_INBUF_SIZE 4096
unsigned char g_Mp3InBuffer[MP3_INBUF_SIZE];

// Ausgangs-Buffer
#define NBUFS  2
#define MP3_OUTBUF_SIZE (MAX_NCHAN * MAX_NGRAN * MAX_NSAMP)
short OutBuffer[NBUFS][MP3_OUTBUF_SIZE];
short* OutBufPtr[NBUFS];
int nSamples[NBUFS];
int PlayCtr=0;


    /* The audio function callback takes the following parameters:
       stream:  A pointer to the audio buffer to be filled
       len:     The length (in chars) of the audio buffer
    */
void fill_audio(void *udata, Uint8 *stream, int len)
{
  // So lange noch Daten gebraucht werden...
  while(len > 0) {
    if(nSamples[PlayCtr] == 0) {
      // Keine Daten zum abspielen
      memset(stream, 0, len);
      break;
    }

    // Daten kopieren...
    if(nSamples[PlayCtr] > len) {
      // Mehr Daten vorhanden als gebraucht werden
      memcpy(stream, (void*)OutBufPtr[PlayCtr], len);
      OutBufPtr[PlayCtr] += len/2;
      nSamples[PlayCtr] -= len;
      len = 0;
    } else {
      // Weniger Daten vorhanden als gebraucht werden
      memcpy(stream, (void*)OutBufPtr[PlayCtr], nSamples[PlayCtr]);
      stream += nSamples[PlayCtr];
      len -= nSamples[PlayCtr];
      OutBufPtr[PlayCtr] = NULL; // Pointer auf null setzen - buffer verbraucht
      nSamples[PlayCtr] = 0; // Anzahl Bytes auf null setzen - buffer verbraucht
      // Nchsten Buffer verwenden
      PlayCtr = (PlayCtr+1)&(NBUFS-1);
    }
  }
}

static int Mp3FillReadBuffer(unsigned char* pInData, int unInDataLeft, FILE* pInFile) {
  int unSpaceLeft = MP3_INBUF_SIZE - unInDataLeft;
  int unRead = 0;

  // move last, small chunk from end of buffer to start, then fill with new data
  memmove(g_Mp3InBuffer, pInData, unInDataLeft);
  unRead = fread(g_Mp3InBuffer + unInDataLeft, 1, unSpaceLeft, pInFile);
  if(unRead < unSpaceLeft)
  {
    // zero-pad to avoid finding false sync word after last frame (from old data in readBuf)
    memset(g_Mp3InBuffer + unInDataLeft + unRead, unSpaceLeft - unRead, 0);
  }
  return unRead;
}


int Mp3Decode(char* pszFile)
{
  int nResult = 0;
  unsigned char* pInData = g_Mp3InBuffer;
  int unInDataLeft = 0;
  FILE* fIn;
  int bEof = FALSE;
  int bOutOfData = FALSE;
  MP3FrameInfo mp3FrameInfo;
  int nFrames=0;
  int nDecodeRes = ERR_MP3_NONE;
  HMP3Decoder hMP3Decoder;
  int nOffset;
  SDL_AudioSpec wanted;
  int i;

  /* Set the audio format */
  wanted.freq = 44100;
  wanted.format = AUDIO_S16;
  wanted.channels = 2;    /* 1 = mono, 2 = stereo */
  wanted.samples = 1024;  /* Good low-latency value for callback */
  wanted.callback = fill_audio;
  wanted.userdata = NULL;

  /* Open the audio device, forcing the desired format */
  if ( SDL_OpenAudio(&wanted, NULL) < 0 ) {
    printf("Couldn't open audio: %s\n", SDL_GetError());
    return(-1);
  }

  nResult =  fopen_s(&fIn, pszFile, "rb");

  hMP3Decoder = MP3InitDecoder();
  if(hMP3Decoder == NULL)
  {
    return -2;
  }

  OutBufPtr[0] = NULL;
  OutBufPtr[1] = NULL;

  SDL_PauseAudio(0);
  do {
    if(unInDataLeft < (2 * MAINBUF_SIZE) && (!bEof))
    {
      int unRead = Mp3FillReadBuffer(pInData, unInDataLeft, fIn);
      unInDataLeft += unRead;
      pInData = g_Mp3InBuffer;
      if(unRead == 0)
      {
        bEof = TRUE;
      }
    }

    // find start of next MP3 frame - assume EOF if no sync found
    nOffset = MP3FindSyncWord(pInData, unInDataLeft);
    if(nOffset < 0)
    {
      // Daten ohne Syncword - ID3, Cover etc.
      pInData += unInDataLeft-8;
      unInDataLeft -= unInDataLeft-8;
      continue;
    } else {
      pInData += nOffset;
      unInDataLeft -= nOffset;
    }
    // decode one MP3 frame - if offset < 0 then charsLeft was less than a full frame
    // Freien Buffer finden
    i=0;
    while(OutBufPtr[i]!=NULL) {
      i= (i+1)&(NBUFS-1);
    }
    nDecodeRes = MP3Decode(hMP3Decoder, &pInData, (int*)&unInDataLeft, (short*)OutBuffer[i], 0);
    switch(nDecodeRes)
    {
      case ERR_MP3_NONE:
      {
        MP3GetLastFrameInfo(hMP3Decoder, &mp3FrameInfo);
        OutBufPtr[i] = OutBuffer[i];
        nSamples[i] = mp3FrameInfo.outputSamps*2;
        break;
      }
      case ERR_MP3_MAINDATA_UNDERFLOW:
      {
        // do nothing - next call to decode will provide more mainData
        break;
      }
      case ERR_MP3_FREE_BITRATE_SYNC:
      {
        break;
      }
      case ERR_MP3_INDATA_UNDERFLOW:
      {
        bOutOfData = TRUE;
        break;
      }
      default:
      {
        bOutOfData = TRUE;
        break;
      }
    }
  }
  while((!bOutOfData) && (nResult == 0) && (!bEof));

  SDL_PauseAudio(1);
  SDL_CloseAudio();

  MP3FreeDecoder(hMP3Decoder);
  fclose(fIn);

  return nResult;
}

int main(int argc, char* argv[])
{
  Mp3Decode("test.mp3");
	return 0;
}



